Learn R Programming

distdrawr (version 0.1.3)

check_species: Check for available distribution data

Description

This function will compare the species or genera in your species list with the entries of the FLORKART-database and returns the matching entries.

Usage

check_species(x, level = "species")

Arguments

x

A data.frame with one column containing the species names in the format 'genus_epithet'.

level

A character string describing wether the check should be conducted on the "species" or "genus" level.

Value

Returns a data frame containing the matching taxon number and species names of x in the FloraWeb database. Mismatches are saved in the attributes of the data frame. The output can be modified and used in get.dist with input = TRUE.

Details

If input data consists only of genus names the function will call level = "genus".

References

Datenbank FLORKART der Floristischen Kartierung Deutschlands, Stand 2013, Bundesamt fuer Naturschutz (BfN) und Netzwerk Phytodiversitaet Deutschland (NetPhyD): http://www.floraweb.de

Examples

Run this code
# NOT RUN {
library("distdrawr")
specieslist <- data.frame(c("Bellis_perennis","Taraxacum_officinale",
                            "Capsella_bursa-pastoris"))
check_species(specieslist, level="species")
# }

Run the code above in your browser using DataLab