Learn R Programming

distdrawr (version 0.1.3)

get.dist: Get distribution data for your species list.

Description

This function downloads distribution data from the FloraWeb-database.

Usage

get.dist(x, input = FALSE, output = "list", matrix.res = "TK25")

Arguments

x

A data.frame with one column containing the species names in the format 'genus_epithet'.

input

logical. If TRUE x is treated as the output of check_species, if FALSE x is treated as the input for check_species with level = "species"

output

A character string describing whether the output format should be a "list" or a "matrix".

matrix.res

A character string describing the resolution of the produced matrix, either "TK25" or "quarterTK".

Value

Output depends on the output value. output = "list" returns a list of one data.frame per taxon, including all information found in the FloraWeb for the particular taxa. output= "matrix" returns a presence/absence matrix for the TK25 plane survey sheets, when matrix.res = "TK25" or the quarter TK25 plane survey sheets, when matrix.res = "quarterTK" including every matching taxon in x.

Details

This function applies functions from the get.dist-family on your species list, depending on the value of output. The default value is list.

References

Datenbank FLORKART der Floristischen Kartierung Deutschlands, Stand 2013, Bundesamt fuer Naturschutz (BfN) und Netzwerk Phytodiversitaet Deutschland (NetPhyD): http://www.floraweb.de

Examples

Run this code
# NOT RUN {
library("distdrawr")
specieslist <- data.frame(c("Bellis_perennis","Abies_alba",
                            "Capsella_bursa-pastoris"))
get.dist(specieslist, output = "list")
# }

Run the code above in your browser using DataLab